Module server

Module server 

Types and tools for protosocket-rpc servers.

See example-proto or example-messagepack for how to make servers.

Structs

LevelSpawn
When everything in your SocketService is Send, and you want a connection to be thread-pinned, you can use a LevelSpawnConnection.
RpcResponder
A request context’s temporary lease to an RPC Reactor’s state. You want to consume your RpcResponder as quickly as possible.
SocketRpcServer
A SocketRpcServer is a server future. It listens on a socket and spawns new connections, with a ConnectionService to handle each connection.
TokioSpawn
When everything in your SocketService is Send, you can use a TokioSpawn.

Traits

ConnectionService
A connection service receives rpcs from clients and sends responses.
SocketService
SocketService receives connections and produces ConnectionServices.
Spawn
A strategy for spawning futures.