RpcResponder

Struct RpcResponder 

pub struct RpcResponder<'a, Response> { /* private fields */ }
A request context’s temporary lease to an RPC Reactor’s state. You want to consume your RpcResponder as quickly as possible.

Implementations

Source

impl<'a, Response> RpcResponder<'a, Response>
where Response: Message,

pub fn unary( self, unary_rpc: impl Future<Output = Response>, ) -> impl Future<Output = ()>

Consume the responder by providing a future that will materialize the response to this request.

pub fn stream( self, streaming_rpc: impl Stream<Item = Response>, ) -> impl Future<Output = ()>

Consume the responder by providing a stream that will materialize the response to this request.

pub fn immediate(self, response: Response)

Consume the responder by providing an immediate response.

This is the cheapest, fastest way to respond, but you must only use it when you can get a response without blocking!