pub struct SocketRpcServer<TSocketService, TSpawnConnection>where
TSocketService: SocketService,{ /* private fields */ }Expand description
A SocketRpcServer is a server future. It listens on a socket and spawns new connections,
with a ConnectionService to handle each connection.
Protosockets use monomorphic messages: You can only have 1 kind of message per service.
The expected way to work with this is to use prost, messagepack, or some other format that
has a notion of a oneof, and list your message types in that.
The socket server hosts your SocketService. Your SocketService creates a ConnectionService for each new connection. Your ConnectionService manages one connection. It is Dropped when the connection is closed.
Implementations
Sourceimpl<TSocketService> SocketRpcServer<TSocketService, TokioSpawn<Connection<<TSocketService::SocketListener as SocketListener>::Stream, TSocketService::Codec, RpcSubmitter<TSocketService::ConnectionService>>>>where
TSocketService: SocketService,
TSocketService::Codec: Send,
<TSocketService::Codec as Encoder>::Serialized: Send,
<TSocketService::SocketListener as SocketListener>::Stream: Send,
TSocketService::ConnectionService: Send,
impl<TSocketService> SocketRpcServer<TSocketService, TokioSpawn<Connection<<TSocketService::SocketListener as SocketListener>::Stream, TSocketService::Codec, RpcSubmitter<TSocketService::ConnectionService>>>>where
TSocketService: SocketService,
TSocketService::Codec: Send,
<TSocketService::Codec as Encoder>::Serialized: Send,
<TSocketService::SocketListener as SocketListener>::Stream: Send,
TSocketService::ConnectionService: Send,
Sourcepub fn new(
listener: TSocketService::SocketListener,
socket_server: TSocketService,
max_buffer_length: usize,
buffer_allocation_increment: usize,
max_queued_outbound_messages: usize,
) -> Result<Self>
pub fn new( listener: TSocketService::SocketListener, socket_server: TSocketService, max_buffer_length: usize, buffer_allocation_increment: usize, max_queued_outbound_messages: usize, ) -> Result<Self>
Construct a new SocketRpcServer with a listener.
This assumes a Tokio runtime, and is only available when your SocketService is
transitively Send.
Sourceimpl<TSocketService, TSpawnConnection> SocketRpcServer<TSocketService, TSpawnConnection>where
TSocketService: SocketService,
TSpawnConnection: Spawn<Connection<<TSocketService::SocketListener as SocketListener>::Stream, TSocketService::Codec, RpcSubmitter<TSocketService::ConnectionService>>>,
impl<TSocketService, TSpawnConnection> SocketRpcServer<TSocketService, TSpawnConnection>where
TSocketService: SocketService,
TSpawnConnection: Spawn<Connection<<TSocketService::SocketListener as SocketListener>::Stream, TSocketService::Codec, RpcSubmitter<TSocketService::ConnectionService>>>,
Sourcepub fn new_with_spawner(
listener: TSocketService::SocketListener,
socket_server: TSocketService,
max_buffer_length: usize,
buffer_allocation_increment: usize,
max_queued_outbound_messages: usize,
spawner: TSpawnConnection,
) -> Result<Self>
pub fn new_with_spawner( listener: TSocketService::SocketListener, socket_server: TSocketService, max_buffer_length: usize, buffer_allocation_increment: usize, max_queued_outbound_messages: usize, spawner: TSpawnConnection, ) -> Result<Self>
Construct a new SocketRpcServer with a listener and a spawner.
Sourcepub fn set_max_buffer_length(&mut self, max_buffer_length: usize)
pub fn set_max_buffer_length(&mut self, max_buffer_length: usize)
Set the maximum buffer length for connections created by this server after the setting is applied.
Sourcepub fn set_max_queued_outbound_messages(
&mut self,
max_queued_outbound_messages: usize,
)
pub fn set_max_queued_outbound_messages( &mut self, max_queued_outbound_messages: usize, )
Set the maximum queued outbound messages for connections created by this server after the setting is applied.