Types and tools for protosocket-rpc servers.
See example-proto or example-messagepack for how to make servers.
Structs
- Level
Spawn - When everything in your
SocketServiceisSend, and you want a connection to be thread-pinned, you can use a LevelSpawnConnection. - RpcResponder
- A request context’s temporary lease to an RPC Reactor’s state. You want to consume your RpcResponder as quickly as possible.
- Socket
RpcServer - A
SocketRpcServeris a server future. It listens on a socket and spawns new connections, with a ConnectionService to handle each connection. - Tokio
Spawn - When everything in your
SocketServiceisSend, you can use a TokioSpawn.
Traits
- Connection
Service - A connection service receives rpcs from clients and sends responses.
- Socket
Service - SocketService receives connections and produces ConnectionServices.
- Spawn
- A strategy for spawning futures.